==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/topics.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001,2002 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
include("include/header.inc.php");

	$ncols = 3;

	$VAR["Heading"]	= _TOPICS;
	$VAR["Content"]	= "<TABLE CELLSPACING=4 CELLPADDING=0 BORDER=0 WIDTH=\"100%\"><tr>\n";
	$i = 0;
	foreach ($TOPIC as $A) {
	    $VAR["Content"] .= "<td align=center>
		 <a href=\"$G_URL/stories.php?topic=$A[Rid]\"><img src=\"$A[ImgURL]\" alt=\"$A[AltTag]\" BORDER=\"0\"></a><br><a href=\"$G_URL/stories.php?topic=$A[Rid]\">$A[Topic]</a></td>\n";
		 $i++;
		 if ($i==$ncols) { $VAR["Content"] .= "<TR>\n"; $i=0; }
	}
	$VAR["Content"]	.= "</tr></table>\n";
	KWL_DrawMain($VAR);

include("include/footer.inc.php");
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/topics.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");
include("include/header.inc.php");

	$ncols = 3;

	$VAR["Heading"]	= _TOPICS;
	$VAR["Content"]	= "<table cellspacing=\"4\" cellpadding=\"0\" border=\"0\" width=\"100%\"><tr>\n";
	$i = 0;
	foreach ($TOPIC as $A) {
	    $VAR["Content"] .= "<td align=\"center\">
		 <a href=\"$G_URL/stories.php?topic=$A[Rid]\"><img src=\"$A[ImgURL]\" alt=\"$A[AltTag]\" border=\"0\" /></a><br /><a href=\"$G_URL/stories.php?topic=$A[Rid]\">$A[Topic]</a></td>\n";
		 $i++;
		 if ($i==$ncols) { $VAR["Content"] .= "<tr>\n"; $i=0; }
	}
	$VAR["Content"]	.= "</tr></table>\n";
	KWL_DrawMain($VAR);

include("include/footer.inc.php");
?>
